User Guide
==========

Documentation is split into four categories, also accessible from links in the
side-bar.

.. grid:: 2
    :gutter: 4

    .. grid-item-card:: :material-regular:`directions_walk;3em`

        .. toctree::
            :caption: Tutorials
            :maxdepth: 1

            tutorials/installation
            tutorials/running-a-simulation
            tutorials/creating-a-simulation
            tutorials/creating-a-device
            tutorials/creating-an-adapter

        +++

        Tutorials for installation and typical usage. New users start here.

    .. grid-item-card:: :material-regular:`directions;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/accomplish-a-task

        +++

        Practical step-by-step guides for the more experienced user.

    .. grid-item-card:: :material-regular:`info;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/glossary
            explanations/how-component-updates-are-ordered

        +++

        Explanations of how the library works and why it works that way.

    .. grid-item-card:: :material-regular:`menu_book;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/api
            ../genindex

        +++

        Technical reference material including APIs and release notes.
